% Outputs steady state or HP-filtered simulated variables
function R = dyn_sssim(flag,M_,oo_)

  % Model parameters
  gam  = M_.params(2);
  nu   = M_.params(3);
  rho  = M_.params(17);
  
  % Verify parameter condition
  if 2 - rho - (gam - rho + 1)*nu <= 0 
    warning('Check your parameters!') %#ok<WNTAG>
  end
  
  switch flag
    
    case 'ss'
      
      % Extract steady state as structure
      R = cell2struct(...
        num2cell(oo_.steady_state),...
        cellstr(M_.endo_names)...
        );
      
    case 'simul'
      
      % Remove first observations from simulation
      [~, V N] = size(oo_);
      remove = 100; 
      oo_ = reshape(oo_(:,:,remove+1:N),V,N-remove);
      
      % Apply HP filter
      ooCell = num2cell(oo_,2);
      R = cellfun(@(x) myhpfilter(x),ooCell,'UniformOutput',false);
      
      % Convert to structure
      R = cell2struct(...
        R,...
        cellstr(M_.endo_names)...
        );
      
    case 'irf'
      
      % Extract impulse responses as structure
      R = oo_.irfs;
      
  end;
    
end

% Takes log if all variables are nonnegative,
% then extracts cyclical component of HP filter
function w = myhpfilter(x)
  if all(x>=0), x = log(x); end
%   diag = eye(length(x));
%   d    = diff(diag,2); 
%   w    = x' - (diag + 1600*(d'*d))\x'; 
  w = x' - hpfilter(x,1600);
end