
function [newss, ssH, ssF, stdH, stdF, acrH, acrF, corH, corF, corHF] = dyn_stats(M_,oo_,oo_sim)

  %global newss

  % Run dynare 
  %dyn_main;
 
  % STEADY STATE PROPERTIES
  
  %SS = dyn_main_steadystate();
  SS = dyn_sssim('ss',M_,oo_);
  
  % Domestic
  ssH = struct(...
    'n',  SS.nH,...
    'c',  SS.mcH/SS.gdpH,...
    'x',  SS.mxH/SS.gdpH,...
    'm',  SS.exF/SS.gdpH,...
    'xk', SS.mxH/SS.kH...
    ); 
  
  
  % Foreign
  ssF = struct(...
    'n',  SS.nF,...
    'c',  SS.mcF/SS.gdpF,...
    'x',  SS.mxF/SS.gdpF,...
    'm',  SS.exH/SS.gdpF,...
    'xk', SS.mxF/SS.kF...
    ); 
  
  % SIMULATED STATISTICS
  
  Nsim = size(oo_sim,1);  
  
  % Initialize matrices
  stdH  = zeros(Nsim,7);
  stdF  = zeros(Nsim,7);
  acrH  = zeros(Nsim,6);
  acrF  = zeros(Nsim,6);
  corH  = zeros(Nsim,7);
  corF  = zeros(Nsim,7);
  corHF = zeros(Nsim,6);

  for i=1:Nsim;

    S = dyn_sssim('simul',M_,oo_sim(i,:,:));

    % Domestic standard deviations
    stdH(i,:) = [
     std(S.gdpH).^2
     std(S.nH)  
     std(S.mcH)   
     std(S.mxH)  
     std(S.nxH) 
     std(S.totH)
     std(S.mYH)  
     ]./std(S.gdpH)';
     
    % Foreign 
    stdF(i,:) = [
     std(S.gdpF).^2
     std(S.nF)  
     std(S.mcF)   
     std(S.mxF)   
     std(S.nxF)  
     std(S.totF)
     std(S.mYF)  
     ]./std(S.gdpF)';
 
    % Domestic autocorrelations
    temp = [
      autocorr(S.gdpH,1)'
      autocorr(S.nH,1)'
      autocorr(S.mcH,1)'
      autocorr(S.mxH,1)'
      autocorr(S.nxH,1)'
      autocorr(S.totH,1)'
      ];
    acrH(i,:) = temp(:,2)';
    
    % Foreign
    temp = [
      autocorr(S.gdpF,1)'
      autocorr(S.nF,1)'
      autocorr(S.mcF,1)'
      autocorr(S.mxF,1)'
      autocorr(S.nxF,1)'
      autocorr(S.totF,1)'
      ];
    acrF(i,:) = temp(:,2)';

    % Domestic correlations between variables
    corH(i,:) = [
     corr(S.gdpH,S.nH) 
     corr(S.gdpH,S.mcH)
     corr(S.gdpH,S.mxH)
     corr(S.gdpH,S.nxH)
     corr(S.gdpH,S.totH)
     corr(S.mcH,S.nH)
     corr(S.mcH,S.mxH)
     ]';
     
   % Foreign
   corF(i,:) = [
     corr(S.gdpH,S.nH) 
     corr(S.gdpH,S.mcH)
     corr(S.gdpH,S.mxH)
     corr(S.gdpH,S.nxH)
     corr(S.gdpH,S.totH)
     corr(S.mcH,S.nH)
     corr(S.mcH,S.mxH)
     ]';
   
   % Cross-country
   corHF(i,:) = [
     corr(S.gdpH,S.gdpF)
     corr(S.nH,S.nF)
     corr(S.mcH,S.mcF)
     corr(S.mxH,S.mxF)
     corr(S.RCF,S.rerF)
     corr(S.RYF,S.rerF)
     ]';

  end
  
  % Labels
  labsd = {'gdp','n','c','x','nx','tt','Y'};
  labac = {'gdp','n','c','x','nx','tt'};
  labcr = {'yn','yc','yx','ynx','ytt','cn','cx'};
  labic = {'yy','nn','cc','xx','rcrer','ryrer'};
  
  % Average over all simulations and create structured output
  makestr = @(X,L) cell2struct(num2cell(mean(X)'),L);
  stdH  = makestr(stdH,labsd);
  stdF  = makestr(stdF,labsd);
  acrH  = makestr(acrH,labac);
  acrF  = makestr(acrF,labac);
  corH  = makestr(corH,labcr);
  corF  = makestr(corF,labcr);
  corHF = makestr(corHF,labic);
  
  % Check convergence to calibration target
%   out = [
%     ssH.n - goal(1)
%     ssH.x - goal(2)  
%     ssH.m - goal(3)
%     ];
  
  
  % Update steady state
  myceil = @(x,y) ceil(x/y)*y;
  newss = [SS.nH SS.nF SS.xH SS.xF SS.wH SS.wF]';
  newss = myceil(newss,0.01);
  
  %fprintf('New parameters : %.2f \n', par');
  %fprintf('Distance to target   : %g \n',norm(out,Inf));
  
end 